==> aliyun-java-sdk-vod-2.15.8-sources.jar: com/aliyuncs/vod/Endpoint.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vod;

import java.util.HashMap;

public class Endpoint {
    public static HashMap<String, String> endpointMap = new HashMap<String, String>() {
        {
            put("cn-shanghai-internal-test-1", "vod.aliyuncs.com");
            put("cn-beijing-gov-1", "vod.aliyuncs.com");
            put("cn-shenzhen-su18-b01", "vod.aliyuncs.com");
            put("cn-beijing", "vod.cn-shanghai.aliyuncs.com");
            put("cn-shanghai-inner", "vod.aliyuncs.com");
            put("cn-shenzhen-st4-d01", "vod.aliyuncs.com");
            put("cn-haidian-cm12-c01", "vod.aliyuncs.com");
            put("cn-hangzhou-internal-prod-1", "vod.aliyuncs.com");
            put("cn-yushanfang", "vod.aliyuncs.com");
            put("cn-qingdao", "vod.aliyuncs.com");
            put("cn-hongkong-finance-pop", "vod.aliyuncs.com");
            put("cn-qingdao-nebula", "vod.aliyuncs.com");
            put("cn-shanghai-finance-1", "vod.aliyuncs.com");
            put("cn-beijing-finance-pop", "vod.aliyuncs.com");
            put("cn-wuhan", "vod.aliyuncs.com");
            put("cn-shenzhen", "vod.cn-shanghai.aliyuncs.com");
            put("cn-zhengzhou-nebula-1", "vod.aliyuncs.com");
            put("rus-west-1-pop", "vod.ap-northeast-1.aliyuncs.com");
            put("cn-shanghai-et15-b01", "vod.aliyuncs.com");
            put("cn-hangzhou-bj-b01", "vod.aliyuncs.com");
            put("cn-hangzhou-internal-test-1", "vod.aliyuncs.com");
            put("eu-west-1-oxs", "vod.ap-northeast-1.aliyuncs.com");
            put("cn-zhangbei-na61-b01", "vod.aliyuncs.com");
            put("cn-beijing-finance-1", "vod.aliyuncs.com");
            put("cn-hangzhou-internal-test-3", "vod.aliyuncs.com");
            put("cn-hangzhou-internal-test-2", "vod.aliyuncs.com");
            put("cn-shenzhen-finance-1", "vod.aliyuncs.com");
            put("me-east-1", "vod.ap-northeast-1.aliyuncs.com");
            put("cn-chengdu", "vod.aliyuncs.com");
            put("cn-hangzhou-test-306", "vod.aliyuncs.com");
            put("cn-shanghai-et2-b01", "vod.aliyuncs.com");
            put("cn-hangzhou-finance", "vod.aliyuncs.com");
            put("cn-beijing-nu16-b01", "vod.aliyuncs.com");
            put("cn-edge-1", "vod.aliyuncs.com");
            put("ap-southeast-2", "vod.ap-northeast-1.aliyuncs.com");
            put("ap-southeast-3", "vod.ap-northeast-1.aliyuncs.com");
            put("cn-huhehaote", "vod.aliyuncs.com");
            put("cn-fujian", "vod.aliyuncs.com");
            put("us-east-1", "vod.ap-northeast-1.aliyuncs.com");
            put("ap-northeast-2-pop", "vod.ap-northeast-1.aliyuncs.com");
            put("cn-shenzhen-inner", "vod.aliyuncs.com");
            put("cn-zhangjiakou-na62-a01", "vod.aliyuncs.com");
            put("cn-hangzhou", "vod.cn-shanghai.aliyuncs.com");
        }
    };

    public static String endpointRegionalType = "regional";
}

==> aliyun-java-sdk-vod-2.15.10-sources.jar: com/aliyuncs/vod/Endpoint.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.vod;

import java.util.HashMap;

public class Endpoint {
    public static HashMap<String, String> endpointMap = new HashMap<String, String>() {
        {
            put("cn-shanghai-internal-test-1", "vod.aliyuncs.com");
            put("cn-beijing-gov-1", "vod.aliyuncs.com");
            put("cn-shenzhen-su18-b01", "vod.aliyuncs.com");
            put("cn-beijing", "vod.cn-shanghai.aliyuncs.com");
            put("cn-wulanchabu", "vod.aliyuncs.com");
            put("cn-shanghai-inner", "vod.aliyuncs.com");
            put("cn-shenzhen-st4-d01", "vod.aliyuncs.com");
            put("cn-haidian-cm12-c01", "vod.aliyuncs.com");
            put("cn-hangzhou-internal-prod-1", "vod.aliyuncs.com");
            put("cn-yushanfang", "vod.aliyuncs.com");
            put("cn-qingdao", "vod.aliyuncs.com");
            put("cn-hongkong-finance-pop", "vod.aliyuncs.com");
            put("cn-qingdao-nebula", "vod.aliyuncs.com");
            put("cn-shanghai-finance-1", "vod.aliyuncs.com");
            put("cn-beijing-finance-pop", "vod.aliyuncs.com");
            put("cn-wuhan", "vod.aliyuncs.com");
            put("cn-zhengzhou-nebula-1", "vod.aliyuncs.com");
            put("rus-west-1-pop", "vod.aliyuncs.com");
            put("cn-shanghai-et15-b01", "vod.aliyuncs.com");
            put("cn-hangzhou-bj-b01", "vod.aliyuncs.com");
            put("cn-hangzhou-internal-test-1", "vod.aliyuncs.com");
            put("eu-west-1-oxs", "vod.aliyuncs.com");
            put("cn-zhangbei-na61-b01", "vod.aliyuncs.com");
            put("cn-beijing-finance-1", "vod.aliyuncs.com");
            put("cn-hangzhou-internal-test-3", "vod.aliyuncs.com");
            put("cn-hangzhou-internal-test-2", "vod.aliyuncs.com");
            put("cn-shenzhen-finance-1", "vod.aliyuncs.com");
            put("me-east-1", "vod.aliyuncs.com");
            put("cn-chengdu", "vod.aliyuncs.com");
            put("cn-hangzhou-test-306", "vod.aliyuncs.com");
            put("cn-huhehaote-nebula-1", "vod.aliyuncs.com");
            put("cn-shanghai-et2-b01", "vod.aliyuncs.com");
            put("cn-hangzhou-finance", "vod.aliyuncs.com");
            put("cn-beijing-nu16-b01", "vod.aliyuncs.com");
            put("cn-edge-1", "vod.aliyuncs.com");
            put("ap-southeast-2", "vod.aliyuncs.com");
            put("ap-southeast-3", "vod.aliyuncs.com");
            put("cn-huhehaote", "vod.aliyuncs.com");
            put("cn-fujian", "vod.aliyuncs.com");
            put("us-east-1", "vod.aliyuncs.com");
            put("ap-northeast-2-pop", "vod.aliyuncs.com");
            put("cn-shenzhen-inner", "vod.aliyuncs.com");
            put("cn-zhangjiakou-na62-a01", "vod.aliyuncs.com");
            put("cn-hangzhou", "vod.cn-shanghai.aliyuncs.com");
        }
    };

    public static String endpointRegionalType = "regional";
}
